@@ -1,4 +1,4 @@
-package Pcore::SMTP v0.5.1;
+package Pcore::SMTP v0.5.2;
 
 use Pcore -dist, -const, -class, -result;
 use Pcore::AE::Handle qw[:TLS_CTX];
@@ -611,7 +611,7 @@ Pcore::SMTP - non-blocking SMTP protocol implementation
         tls      => 1,
     } );
 
-    # send email with two attachmants
+    # send email with two attachments
     $message_body = [ [ 'filename1.ext', \$content1 ], [ 'filename2.ext', \$content2 ] ];
 
     $smtp->sendmail(
@@ -681,11 +681,15 @@ Examples:
 
     $body = \'message body';
 
-    $body = [ $part1, \$part2, [ \@headers, $content ] ];
+    $body = [ 'body1', \$body2, [ \@headers, $content ] ];
 
     # send email with two file attachmants
     $body = [ 'message body', [ 'filename1.txt', \$content1 ], [ 'filename2.txt', \$content2 ] ];
 
+    # manually specify headers
+    # send HTML email with 1 attachment
+    $body = [ [ ['Content-Type: text/html'], \$body ], [ 'filename1.txt', \$attachment ] ];
+
 =back
 
 =head1 NOTES
